@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::Reports::Receiver::Daemon::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::Reports::Receiver::Daemon::VERSION = '4.0.1';
+  $Tapper::Reports::Receiver::Daemon::VERSION = '4.1.0';
 }
 
 use 5.010;
@@ -13,6 +13,7 @@ use warnings;
 
 use Tapper::Config;
 use Tapper::Reports::Receiver;
+use Log::Log4perl;
 use Moose;
 
 with 'MooseX::Daemonize';
@@ -21,10 +22,14 @@ after start => sub {
                     my $self = shift;
 
                     return unless $self->is_daemon;
-        my $port = Tapper::Config->subconfig->{report_port};
 
 
-        Tapper::Reports::Receiver->new()->run($port);
+
+                    my $logconf = Tapper::Config->subconfig->{files}{log4perl_cfg};
+                    Log::Log4perl->init($logconf);
+
+                    my $port = Tapper::Config->subconfig->{report_port};
+                    Tapper::Reports::Receiver->new()->run($port);
 };
 
 
